@@ -15,19 +15,21 @@ import config as sys_config
 
 class ToEver():
     def __init__(self, token, sandbox=True):
+        self.client = EvernoteClient(token=token, sandbox=sandbox)
         self.token = token
-        self.client = EvernoteClient(token=self.token, sandbox=sandbox)
+        self.hide = False
+        self.share = False
+        self.tag = None
+        self.bookguid = None
 
-    def createNote(self, title, content, share=False, tag=None, bookguid=None, resource=None):
+    def createNote(self, title, content, resource=None):
         user_store = self.client.get_user_store()
         note_store = self.client.get_note_store()
         try:
             note = Note()
-            if not tag is None:
-                note.tagNames = tag
-            if not bookguid is None:
-                note.notebookGuid = bookguid
-            if not resource is None:
+            note.tagNames = self.tag
+            note.notebookGuid = self.bookguid
+            if resource is not None:
                 note.resources = [resource]
                 content += "<span><en-media type=\"%s\" hash=\"%s\"/></span>" % (resource.mime, resource.data.bodyHash)
             note.title = title
@@ -36,14 +38,25 @@ class ToEver():
             note.content += "<en-note>%s</en-note>" % content
             created_note = note_store.createNote(note)
         except:
-            print "\n" + textui.colored.red('Create note error')
-            return 1
-        print "\n" + ToEver.getUserUploadState(note_store.getSyncState().uploaded, user_store.getUser().accounting.uploadLimitNextMonth)
-        print textui.colored.blue("Created note title is '" + title + "'")
-        if share:
-            print textui.colored.blue(
-                "Get note share url --> " + ToEver.getNoteShareUrl(sys_config.evernote_url, user_store.getUser().shardId, created_note.guid, note_store.shareNote(self.token, created_note.guid))
+            return textui.colored.red('Create note error')
+
+        note_share_url = None
+        if self.share:
+            note_share_url = ToEver.getNoteShareUrl(
+                sys_config.evernote_url,
+                user_store.getUser().shardId,
+                created_note.guid,
+                note_store.shareNote(self.token, created_note.guid)
             )
+
+        if not self.hide:
+            message = "\n" + ToEver.getUserUploadState(note_store.getSyncState().uploaded, user_store.getUser().accounting.uploadLimitNextMonth)
+            message += "\n" + "Created note title is '" + title + "'"
+            if note_share_url is not None:
+                message += "\n" + "Share URL --> " + note_share_url
+            print(textui.colored.blue(message))
+        elif note_share_url is not None:
+            print(textui.colored.blue(note_share_url))
         return 0
 
     def listNotebooks(self):
@@ -106,13 +119,13 @@ class UserConfig():
                 return self
 
     def setDefaultNotebook(self):
-        print(textui.colored.green('Set ToEver default post notebook / Not enter if you do not set'))
+        print(textui.colored.green('Set toEver default post notebook / Not enter if you do not set'))
         notebook = raw_input('Notebook: ')
         self.user_config.set(sys_config.application_name, 'notebook', notebook)
         return self
 
     def setDefaultTags(self):
-        print(textui.colored.green('Set ToEver default post tags / Not enter if you do not set'))
+        print(textui.colored.green('Set toEver default post tags / Not enter if you do not set'))
         tags = raw_input('Tags: ')
         self.user_config.set(sys_config.application_name, 'tags', tags)
         return self
@@ -151,7 +164,8 @@ def main():
     parser.add_argument('-f', '--filename', type=str, help='note attachment file name')
     parser.add_argument('--tags', type=str, help='note tags (multiple tag separated by comma.)')
     parser.add_argument('--notebook', type=str, help='note notebook')
-    parser.add_argument('--share', action='store_true', help='get create note share url')
+    parser.add_argument('--share', action='store_true', help='get note share url')
+    parser.add_argument('--hide', action='store_true', help='hide the display')
     parser.add_argument('--config', action='store_true', help='set user config')
     parser.add_argument('-v', '--version', action='version', version='%(prog)s ' + sys_config.version)
 
@@ -164,60 +178,53 @@ def main():
             user_config.setDeveloperToken().setDefaultNotebook().setDefaultTags().save()
         except:
             return 1
-
         return 0
 
     # File check
-    if not args.file is None:
+    if args.file is not None:
         if not os.path.isfile(args.file):
-            print(textui.colored.red('File does not exist ' + args.file))
-            return 1
+            return textui.colored.red('File does not exist ' + args.file)
         sys.stdin = open(args.file, 'r')
         if Util.isBinary(open(args.file, 'r').read()) and args.filename is None:
-            args.filename = args.file
-
-    # Get note title
-    note_title = args.title
-    if args.title is None:
-        note_title = 'ToEver Post ' + datetime.now().strftime('%Y-%m-%d %H:%M:%S')
-
-    # Get note tags
-    note_tags = None
-
-    if args.tags is None and user_config.getUserOption('tags'):
-        args.tags = user_config.getUserOption('tags')
-
-    if not args.tags is None:
-        note_tags = args.tags.split(',')
+            args.filename = os.path.basename(args.file)
 
     # Get user developer token
     stdin_dafault = sys.stdin
     sys.stdin = open('/dev/tty', 'rt')
-
     if not user_config.isDeveloperToken(keyring.get_password(sys_config.application_name, 'developer_token'), sys_config.sandbox):
         user_config.setDeveloperToken()
-
     sys.stdin = stdin_dafault
 
     toever = ToEver(keyring.get_password(sys_config.application_name, 'developer_token'), sys_config.sandbox)
 
-    # Set note bookguid
-    note_bookguid = None
+    # Get note title
+    if args.title is None:
+        args.title = 'toEver Post ' + datetime.now().strftime('%Y-%m-%d %H:%M:%S')
 
+    # Get note tags
+    if args.tags is None and user_config.getUserOption('tags'):
+        args.tags = user_config.getUserOption('tags')
+    if args.tags is not None:
+        toever.tag = args.tags.split(',')
+
+    # Set note bookguid
     if args.notebook is None and user_config.getUserOption('notebook'):
         args.notebook = user_config.getUserOption('notebook')
-
-    if not args.notebook is None:
+    if args.notebook is not None:
         for line in toever.listNotebooks():
             if line.name == args.notebook:
-                note_bookguid = line.guid
+                toever.bookguid = line.guid
                 break
 
+    # Set note tags share
+    toever.hide = args.hide
+    toever.share = args.share
+
     # Set note content
     note_content = str()
 
     # Set binary stream
-    if not args.filename is None:
+    if args.filename is not None:
         data = Data()
         data.body = sys.stdin.read()
         data.size = len(data.body)
@@ -228,20 +235,23 @@ def main():
         attr = ResourceAttributes()
         attr.fileName = args.filename
         resource.attributes = attr
-        return toever.createNote(note_title, note_content, args.share, note_tags, note_bookguid, resource)
+        if not args.hide:
+            print(textui.colored.green("Attachment file is '" + attr.fileName + "'"))
+        return toever.createNote(args.title, note_content, resource)
 
     # Set text stream
     try:
         for line in iter(sys.stdin.readline, ''):
             note_content += toever.getContentFormat(line)
-            print(textui.colored.green(line.rstrip()))
+            if not args.hide:
+                print(textui.colored.green(line.rstrip()))
     except:
         pass
     finally:
         # create note
         if toever.isSetContent(note_content):
-            return toever.createNote(note_title, note_content, args.share, note_tags, note_bookguid)
-    return 1
+            return toever.createNote(args.title, note_content)
+    return textui.colored.red('Create note error')
 
 
 if __name__ == "__main__":
